package mysql

import (
	"context"
	"fmt"
	"gorm.io/gen"
	"pji_desktop_http/biz/dal/query"
	"pji_desktop_http/biz/model"
	"pji_desktop_http/common/config"
)

func AddDeviceMapOneRecord(ctx context.Context, record model.DeviceMap) error {
	r := query.DeviceMap
	err := r.WithContext(ctx).Create(&record)
	return err
}

func UpdateDeviceMapOneRecord(ctx context.Context, record model.DeviceMap) (gen.ResultInfo, error) {
	r := query.DeviceMap
	fmt.Println("record update", record)
	info, err := r.WithContext(ctx).Where(r.ID.Eq(record.ID)).Updates(record)
	if err != nil {
		return info, err
	}
	return info, nil
}

func QueryValidDeviceMapByMapId(ctx context.Context, mapId string) ([]*model.DeviceMap, error) {
	r := query.DeviceMap
	deviceMaps, err := r.WithContext(ctx).Where(r.MapID.Eq(mapId), r.MapValidFlag.Eq(config.MAP_VALID_FLAG)).Find()
	if err != nil {
		return nil, err
	}
	return deviceMaps, nil
}

func QueryValidDeviceMapByDeviceNo(ctx context.Context, deviceNo string) ([]*model.DeviceMap, error) {
	r := query.DeviceMap
	deviceMaps, err := r.WithContext(ctx).Where(r.DeviceNo.Eq(deviceNo), r.MapValidFlag.Eq(config.MAP_VALID_FLAG)).Find()
	if err != nil {
		return nil, err
	}
	return deviceMaps, nil
}

//func QueryValidDeviceMapByMapIdAndDevice(ctx context.Context, mapId string, deviceNo string) ([]*model.DeviceMap, error) {
//	r := query.DeviceMap
//	deviceMaps, err := r.WithContext(ctx).Where(r.MapID.Eq(mapId), r.DeviceNo.Eq(deviceNo), r.MapValidFlag.Eq(config.MAP_VALID_FLAG)).Find()
//	if err != nil {
//		return nil, err
//	}
//	return deviceMaps, nil
//}

func QueryValidDeviceMapByMapIdAndDeviceNo(ctx context.Context, mapId string, deviceNo string) ([]*model.DeviceMap, error) {
	r := query.DeviceMap
	deviceMaps, err := r.WithContext(ctx).Where(r.MapID.Eq(mapId), r.DeviceNo.Eq(deviceNo), r.MapValidFlag.Eq(config.MAP_VALID_FLAG)).Find()
	if err != nil {
		return nil, err
	}
	return deviceMaps, nil
}

func UpdateDeviceMapValidFlagByMapId(ctx context.Context, mapId string, flag int) (gen.ResultInfo, error) {
	r := query.DeviceMap
	info, err := r.WithContext(ctx).Where(r.MapID.Eq(mapId)).Update(r.MapValidFlag, flag)
	if err != nil {
		return info, err
	}
	return info, nil
}

func UpdateDeviceMapValidFlagByDeviceNo(ctx context.Context, deviceNo string, flag int) (gen.ResultInfo, error) {
	r := query.DeviceMap
	info, err := r.WithContext(ctx).Where(r.DeviceNo.Eq(deviceNo)).Update(r.MapValidFlag, flag)
	if err != nil {
		return info, err
	}
	return info, nil
}

func UpdateDeviceMapValidFlagByMapIdAndDevice(ctx context.Context, mapId string, deviceNo string, flag int) (gen.ResultInfo, error) {
	r := query.DeviceMap
	info, err := r.WithContext(ctx).Where(r.MapID.Eq(mapId), r.DeviceNo.Eq(deviceNo)).Update(r.MapValidFlag, flag)
	if err != nil {
		return info, err
	}
	return info, nil
}
